<?php
/**
 * Physiotherapy Lite Theme Customizer
 *
 * @package Physiotherapy Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function physiotherapy_lite_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'physiotherapy_lite_custom_controls' );

function physiotherapy_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'physiotherapy_lite_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'physiotherapy_lite_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$PhysiotherapyLiteParentPanel = new Physiotherapy_Lite_WP_Customize_Panel( $wp_customize, 'physiotherapy_lite_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'physiotherapy-lite' ),
		'priority' => 10,
	));

	$wp_customize->add_panel( $PhysiotherapyLiteParentPanel );

	$HomePageParentPanel = new Physiotherapy_Lite_WP_Customize_Panel( $wp_customize, 'physiotherapy_lite_homepage_panel', array(
		'title' => __( 'Homepage Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id',
	));

	$wp_customize->add_panel( $HomePageParentPanel );

	//Top Bar
	$wp_customize->add_section( 'physiotherapy_lite_topbar', array(
    	'title'      => __( 'Top Bar Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_homepage_panel'
	) );

	$wp_customize->add_setting('physiotherapy_lite_header_img_position',array(
	  'default' => 'center top',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_header_img_position',array(
		'type' => 'select',
		'label' => __('Header Image Position','physiotherapy-lite'),
		'section' => 'header_image',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'physiotherapy-lite' ),
			'center top'   => esc_html__( 'Top', 'physiotherapy-lite' ),
			'right top'   => esc_html__( 'Top Right', 'physiotherapy-lite' ),
			'left center'   => esc_html__( 'Left', 'physiotherapy-lite' ),
			'center center'   => esc_html__( 'Center', 'physiotherapy-lite' ),
			'right center'   => esc_html__( 'Right', 'physiotherapy-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'physiotherapy-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'physiotherapy-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'physiotherapy-lite' ),
		),
	));

	$wp_customize->add_setting( 'physiotherapy_lite_topbar_hide_show',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_topbar_hide_show',array(
		'label' => esc_html__( 'Show / Hide Topbar','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_topbar'
    )));

    //Sticky Header
	$wp_customize->add_setting( 'physiotherapy_lite_sticky_header',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_topbar'
    )));

    $wp_customize->add_setting('physiotherapy_lite_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_header_cart',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_header_cart',array(
      	'label' => esc_html__( 'Show / Hide Cart','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_topbar'
    )));
	
	$wp_customize->add_setting( 'physiotherapy_lite_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_topbar'
    )));

    $wp_customize->add_setting('physiotherapy_lite_search_icon',array(
		'default'	=> 'fas fa-search',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_search_icon',array(
		'label'	=> __('Add Search Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_topbar',
		'setting'	=> 'physiotherapy_lite_search_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('physiotherapy_lite_search_close_icon',array(
		'default'	=> 'fa fa-window-close',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_search_close_icon',array(
		'label'	=> __('Add Search Close Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_topbar',
		'setting'	=> 'physiotherapy_lite_search_close_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting('physiotherapy_lite_search_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_search_font_size',array(
		'label'	=> __('Search Font Size','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_search_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_search_padding_top_bottom',array(
		'label'	=> __('Search Padding Top Bottom','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_search_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_search_padding_left_right',array(
		'label'	=> __('Search Padding Left Right','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_search_border_radius', array(
		'default'              => "",
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_search_border_radius', array(
		'label'       => esc_html__( 'Search Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_topbar',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('physiotherapy_lite_search_placeholder',array(
       'default' => esc_html__('Search','physiotherapy-lite'),
       'sanitize_callback'	=> 'sanitize_text_field'
    ));
    $wp_customize->add_control('physiotherapy_lite_search_placeholder',array(
       'type' => 'text',
       'label' => __('Search Placeholder Text','physiotherapy-lite'),
       'section' => 'physiotherapy_lite_topbar'
    ));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('physiotherapy_lite_call', array( 
		'selector' => '.top-bar p', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_call', 
	));

    $wp_customize->add_setting('physiotherapy_lite_phone_icon',array(
		'default'	=> 'fas fa-phone',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_phone_icon',array(
		'label'	=> __('Add Phone Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_topbar',
		'setting'	=> 'physiotherapy_lite_phone_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('physiotherapy_lite_call',array(
		'default'=> '',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_phone_number'
	));
	$wp_customize->add_control('physiotherapy_lite_call',array(
		'label'	=> __('Add Phone Number','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '+00 1234 567 890', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_header_cart_icon',array(
		'default'	=> 'fas fa-shopping-basket',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_header_cart_icon',array(
		'label'	=> __('Add Cart Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_topbar',
		'setting'	=> 'physiotherapy_lite_header_cart_icon',
		'type'		=> 'icon'
	)));

   	//Menus Settings
	$wp_customize->add_section( 'physiotherapy_lite_menu_section' , array(
    	'title' => __( 'Menus Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_homepage_panel'
	) );

    $wp_customize->add_setting('physiotherapy_lite_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_navigation_menu_font_weight',array(
        'default' => 500,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_menu_section',
        'choices' => array(
        	'100' => __('100','physiotherapy-lite'),
            '200' => __('200','physiotherapy-lite'),
            '300' => __('300','physiotherapy-lite'),
            '400' => __('400','physiotherapy-lite'),
            '500' => __('500','physiotherapy-lite'),
            '600' => __('600','physiotherapy-lite'),
            '700' => __('700','physiotherapy-lite'),
            '800' => __('800','physiotherapy-lite'),
            '900' => __('900','physiotherapy-lite'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('physiotherapy_lite_menu_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','physiotherapy-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','physiotherapy-lite'),
            'Capitalize' => __('Capitalize','physiotherapy-lite'),
            'Lowercase' => __('Lowercase','physiotherapy-lite'),
        ),
		'section'=> 'physiotherapy_lite_menu_section',
	));

	$wp_customize->add_setting('physiotherapy_lite_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_menus_item_style',array(
        'type' => 'select',
        'section' => 'physiotherapy_lite_menu_section',
		'label' => __('Menu Item Hover Style','physiotherapy-lite'),
		'choices' => array(
            'None' => __('None','physiotherapy-lite'),
            'Zoom In' => __('Zoom In','physiotherapy-lite'),
        ),
	) );

	$wp_customize->add_setting('physiotherapy_lite_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_header_menus_color', array(
		'label'    => __('Menus Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_menu_section',
	)));

	$wp_customize->add_setting('physiotherapy_lite_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_menu_section',
	)));

	$wp_customize->add_setting('physiotherapy_lite_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_menu_section',
	)));

	$wp_customize->add_setting('physiotherapy_lite_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_menu_section',
	)));

	//Social links
	$wp_customize->add_section(
		'physiotherapy_lite_social_links', array(
			'title'		=>	__('Social Links', 'physiotherapy-lite'),
			'priority'	=>	null,
			'panel'		=>	'physiotherapy_lite_homepage_panel'
		));

	$wp_customize->add_setting('physiotherapy_lite_social_icons',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_social_icons',array(
		'label' =>  __('Steps to setup social icons','physiotherapy-lite'),
		'description' => __('<p>1. Go to Dashboard >> Appearance >> Widgets</p>
			<p>2. Add Vw Social Icon Widget in Social Media.</p>
			<p>3. Add social icons url and save.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_social_links',
		'type'=> 'hidden'
	));
	$wp_customize->add_setting('physiotherapy_lite_social_icon_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_social_icon_btn',array(
		'description' => "<a target='_blank' href='". admin_url('widgets.php') ." '>Setup Social Icons</a>",
		'section'=> 'physiotherapy_lite_social_links',
		'type'=> 'hidden'
	));
    
	//Slider
	$wp_customize->add_section( 'physiotherapy_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'physiotherapy-lite' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/physiotherapy-wordpress-theme/">GET PRO</a>','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_homepage_panel'
	) );

	$wp_customize->add_setting( 'physiotherapy_lite_slider_arrows',array(
    	'default' => 0,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_slidersettings'
    )));

    $wp_customize->add_setting('physiotherapy_lite_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	) );
	$wp_customize->add_control('physiotherapy_lite_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','physiotherapy-lite'),
            'Advance slider' => __('Advance slider','physiotherapy-lite'),
        ),
	));

	$wp_customize->add_setting('physiotherapy_lite_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'physiotherapy_lite_advance_slider'
	));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('physiotherapy_lite_slider_arrows',array(
		'selector'        => '#slider .inner_carousel h1',
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_slider_arrows',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'physiotherapy_lite_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'physiotherapy_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'physiotherapy_lite_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'physiotherapy-lite' ),
			'description' => __('Slider image size (1600 x 600)','physiotherapy-lite'),
			'section'  => 'physiotherapy_lite_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'physiotherapy_lite_default_slider'
		) );
	}

	$wp_customize->add_setting('physiotherapy_lite_slider_button_text',array(
		'default'=> 'Read More',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'physiotherapy_lite_default_slider'
	));

	$wp_customize->add_setting('physiotherapy_lite_topbar_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('physiotherapy_lite_topbar_btn_link',array(
		'label'	=> esc_html__('Add Button Link','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_slidersettings',
		'type'=> 'url'
	));

	//content layout
	$wp_customize->add_setting('physiotherapy_lite_slider_content_option',array(
        'default' => 'Center',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ),'active_callback' => 'physiotherapy_lite_default_slider'
    )));

    //Slider content padding
    $wp_customize->add_setting('physiotherapy_lite_slider_content_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_slider_content_padding_top_bottom',array(
		'label'	=> __('Slider Content Padding Top Bottom','physiotherapy-lite'),
		'description'	=> __('Enter a value in %. Example:20%','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'physiotherapy_lite_default_slider'
	));

	$wp_customize->add_setting('physiotherapy_lite_slider_content_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_slider_content_padding_left_right',array(
		'label'	=> __('Slider Content Padding Left Right','physiotherapy-lite'),
		'description'	=> __('Enter a value in %. Example:20%','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '50%', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'physiotherapy_lite_default_slider'
	));

    //Slider excerpt
	$wp_customize->add_setting( 'physiotherapy_lite_slider_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_slidersettings',
		'type'        => 'range',
		'settings'    => 'physiotherapy_lite_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),'active_callback' => 'physiotherapy_lite_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('physiotherapy_lite_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_slider_height',array(
		'label'	=> __('Slider Height','physiotherapy-lite'),
		'description'	=> __('Specify the slider height (px).','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_slidersettings',
		'type'=> 'text',
		'active_callback' => 'physiotherapy_lite_default_slider'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_float'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','physiotherapy-lite'),
		'section' => 'physiotherapy_lite_slidersettings',
		'type'  => 'number',
		'active_callback' => 'physiotherapy_lite_default_slider'
	) );

	//Opacity
	$wp_customize->add_setting('physiotherapy_lite_slider_opacity_color',array(
      'default'              => 0.3,
      'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));

	$wp_customize->add_control( 'physiotherapy_lite_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','physiotherapy-lite' ),
	'section'     => 'physiotherapy_lite_slidersettings',
	'type'        => 'select',
	'settings'    => 'physiotherapy_lite_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','physiotherapy-lite'),
      '0.1' =>  esc_attr('0.1','physiotherapy-lite'),
      '0.2' =>  esc_attr('0.2','physiotherapy-lite'),
      '0.3' =>  esc_attr('0.3','physiotherapy-lite'),
      '0.4' =>  esc_attr('0.4','physiotherapy-lite'),
      '0.5' =>  esc_attr('0.5','physiotherapy-lite'),
      '0.6' =>  esc_attr('0.6','physiotherapy-lite'),
      '0.7' =>  esc_attr('0.7','physiotherapy-lite'),
      '0.8' =>  esc_attr('0.8','physiotherapy-lite'),
      '0.9' =>  esc_attr('0.9','physiotherapy-lite')
	),'active_callback' => 'physiotherapy_lite_default_slider'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_slider_image_overlay',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
   ));
   $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_slider_image_overlay',array(
      	'label' => esc_html__( 'Show / Hide Slider Image Overlay','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_slidersettings',
      	'active_callback' => 'physiotherapy_lite_default_slider'
   )));

   $wp_customize->add_setting('physiotherapy_lite_slider_image_overlay_color', array(
		'default'           => '#252f3b',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_slider_image_overlay_color', array(
		'label'    => __('Slider Image Overlay Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_slidersettings',
		'active_callback' => 'physiotherapy_lite_default_slider'
	)));
 
	//Services
	$wp_customize->add_section('physiotherapy_lite_services',array(
		'title'	=> __('Services Section','physiotherapy-lite'),
		'description' => __('For more options of the Services section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/physiotherapy-wordpress-theme/">GET PRO</a>','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_homepage_panel',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'physiotherapy_lite_section_text', array( 
		'selector' => '#physio-services h2', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_section_text',
	));

	$wp_customize->add_setting('physiotherapy_lite_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_section_text',array(
		'label'	=> __('Section Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Services', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_services',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('physiotherapy_lite_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_section_title',array(
		'label'	=> __('Section Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'OUR PHYSIOTHERAPY', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_services',
		'type'=> 'text'
	));	

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';	
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('physiotherapy_lite_services_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('physiotherapy_lite_services_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Latest Post','physiotherapy-lite'),
		'section' => 'physiotherapy_lite_services',
	));

	//About Us Section
	$wp_customize->add_section('physiotherapy_lite_about', array(
		'title'       => __('About Us Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_about_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_about_text',array(
		'description' => __('<p>1. More options for about us section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for about us section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_about',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_about_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_about_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_about',
		'type'=> 'hidden'
	));

	//Banner Section
	$wp_customize->add_section('physiotherapy_lite_banner', array(
		'title'       => __('Banner Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_banner_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_banner_text',array(
		'description' => __('<p>1. More options for banner section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for banner section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_banner',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_banner_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_banner_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_banner',
		'type'=> 'hidden'
	));

	//Records Section
	$wp_customize->add_section('physiotherapy_lite_records', array(
		'title'       => __('Records Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_records_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_records_text',array(
		'description' => __('<p>1. More options for records section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for records section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_records',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_records_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_records_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_records',
		'type'=> 'hidden'
	));

	//Project Section
	$wp_customize->add_section('physiotherapy_lite_project', array(
		'title'       => __('Project Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_project_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_project_text',array(
		'description' => __('<p>1. More options for project section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for project section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_project',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_project_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_project_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_project',
		'type'=> 'hidden'
	));

	//Newsletter Section
	$wp_customize->add_section('physiotherapy_lite_newsletter', array(
		'title'       => __('Newsletter Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_newsletter_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_newsletter_text',array(
		'description' => __('<p>1. More options for newsletter section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for newsletter section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_newsletter',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_newsletter_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_newsletter_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_newsletter',
		'type'=> 'hidden'
	));

	//Video Price Section
	$wp_customize->add_section('physiotherapy_lite_video_price', array(
		'title'       => __('Video Price Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_video_price_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_video_price_text',array(
		'description' => __('<p>1. More options for video price section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for video price section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_video_price',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_video_price_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_video_price_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_video_price',
		'type'=> 'hidden'
	));

	//Testimonial Section
	$wp_customize->add_section('physiotherapy_lite_testimonial', array(
		'title'       => __('Testimonial Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_testimonial_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_testimonial_text',array(
		'description' => __('<p>1. More options for testimonial section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonial section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_testimonial',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_testimonial_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_testimonial_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_testimonial',
		'type'=> 'hidden'
	));

	//Partners Section
	$wp_customize->add_section('physiotherapy_lite_partners', array(
		'title'       => __('Partners Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_partners_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_partners_text',array(
		'description' => __('<p>1. More options for partners section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for partners section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_partners',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_partners_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_partners_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_partners',
		'type'=> 'hidden'
	));

	//Team Section
	$wp_customize->add_section('physiotherapy_lite_team', array(
		'title'       => __('Team Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_team_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_team_text',array(
		'description' => __('<p>1. More options for team section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for team section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_team',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_team_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_team_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_team',
		'type'=> 'hidden'
	));

	//features Section
	$wp_customize->add_section('physiotherapy_lite_features', array(
		'title'       => __('Features Section', 'physiotherapy-lite'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','physiotherapy-lite'),
		'priority'    => null,
		'panel'       => 'physiotherapy_lite_homepage_panel',
	));

	$wp_customize->add_setting('physiotherapy_lite_features_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_features_text',array(
		'description' => __('<p>1. More options for features section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for features section.</p>','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_features',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('physiotherapy_lite_features_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_features_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=physiotherapy_lite_guide') ." '>More Info</a>",
		'section'=> 'physiotherapy_lite_features',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('physiotherapy_lite_footer',array(
		'title'	=> __('Footer Settings','physiotherapy-lite'),
		'description' => __('For more options of the footer section</br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/physiotherapy-wordpress-theme/">GET PRO</a>','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_homepage_panel',
	));	

	$wp_customize->add_setting( 'physiotherapy_lite_footer_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_footer_hide_show',array(
      'label' => esc_html__( 'Show / Hide Footer','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_footer'
    )));

    	// font size
	$wp_customize->add_setting('physiotherapy_lite_button_footer_font_size',array(
		'default'=> 30,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_footer_font_size',array(
		'label'	=> __('Footer Heading Font Size','physiotherapy-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'physiotherapy_lite_footer',
	));

	$wp_customize->add_setting('physiotherapy_lite_button_footer_heading_letter_spacing',array(
		'default'=> 1,
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_footer_heading_letter_spacing',array(
		'label'	=> __('Heading Letter Spacing','physiotherapy-lite'),
  		'type'        => 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
	),
		'section'=> 'physiotherapy_lite_footer',
	));

	// text trasform
	$wp_customize->add_setting('physiotherapy_lite_button_footer_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_button_footer_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Heading Text Transform','physiotherapy-lite'),
		'choices' => array(
      'Uppercase' => __('Uppercase','physiotherapy-lite'),
      'Capitalize' => __('Capitalize','physiotherapy-lite'),
      'Lowercase' => __('Lowercase','physiotherapy-lite'),
    ),
		'section'=> 'physiotherapy_lite_footer',
	));

	$wp_customize->add_setting('physiotherapy_lite_footer_heading_weight',array(
        'default' => 600,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_footer_heading_weight',array(
        'type' => 'select',
        'label' => __('Heading Font Weight','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_footer',
        'choices' => array(
        	'100' => __('100','physiotherapy-lite'),
            '200' => __('200','physiotherapy-lite'),
            '300' => __('300','physiotherapy-lite'),
            '400' => __('400','physiotherapy-lite'),
            '500' => __('500','physiotherapy-lite'),
            '600' => __('600','physiotherapy-lite'),
            '700' => __('700','physiotherapy-lite'),
            '800' => __('800','physiotherapy-lite'),
            '900' => __('900','physiotherapy-lite'),
        ),
	) );

  $wp_customize->add_setting('physiotherapy_lite_footer_template',array(
      'default'	=> esc_html('physiotherapy_lite-footer-one'),
      'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
  ));
  $wp_customize->add_control('physiotherapy_lite_footer_template',array(
          'label'	=> esc_html__('Footer style','physiotherapy-lite'),
          'section'	=> 'physiotherapy_lite_footer',
          'setting'	=> 'physiotherapy_lite_footer_template',
          'type' => 'select',
          'choices' => array(
              'physiotherapy_lite-footer-one' => esc_html__('Style 1', 'physiotherapy-lite'),
              'physiotherapy_lite-footer-two' => esc_html__('Style 2', 'physiotherapy-lite'),
              'physiotherapy_lite-footer-three' => esc_html__('Style 3', 'physiotherapy-lite'),
              'physiotherapy_lite-footer-four' => esc_html__('Style 4', 'physiotherapy-lite'),
              'physiotherapy_lite-footer-five' => esc_html__('Style 5', 'physiotherapy-lite'),
              )
  ));
  
	$wp_customize->add_setting('physiotherapy_lite_footer_background_color', array(
		'default'           => '#252f3b',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_footer_background_color', array(
		'label'    => __('Footer Background Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_footer',
	)));

	$wp_customize->add_setting('physiotherapy_lite_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'physiotherapy_lite_footer_background_image',array(
        'label' => __('Footer Background Image','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_footer'
	)));

	$wp_customize->add_setting('physiotherapy_lite_footer_img_position',array(
	  'default' => 'center center',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_footer_img_position',array(
		'type' => 'select',
		'label' => __('Footer Image Position','physiotherapy-lite'),
		'section' => 'physiotherapy_lite_footer',
		'choices' 	=> array(
			'left top' 		=> esc_html__( 'Top Left', 'physiotherapy-lite' ),
			'center top'   => esc_html__( 'Top', 'physiotherapy-lite' ),
			'right top'   => esc_html__( 'Top Right', 'physiotherapy-lite' ),
			'left center'   => esc_html__( 'Left', 'physiotherapy-lite' ),
			'center center'   => esc_html__( 'Center', 'physiotherapy-lite' ),
			'right center'   => esc_html__( 'Right', 'physiotherapy-lite' ),
			'left bottom'   => esc_html__( 'Bottom Left', 'physiotherapy-lite' ),
			'center bottom'   => esc_html__( 'Bottom', 'physiotherapy-lite' ),
			'right bottom'   => esc_html__( 'Bottom Right', 'physiotherapy-lite' ),
		),
	)); 

	// Footer
	$wp_customize->add_setting('physiotherapy_lite_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','physiotherapy-lite'),
		'choices' => array(
            'fixed' => __('fixed','physiotherapy-lite'),
            'scroll' => __('scroll','physiotherapy-lite'),
        ),
		'section'=> 'physiotherapy_lite_footer',
	));

	$wp_customize->add_setting('physiotherapy_lite_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_footer',
        'choices' => array(
        	'Left' => __('Left','physiotherapy-lite'),
            'Center' => __('Center','physiotherapy-lite'),
            'Right' => __('Right','physiotherapy-lite')
        ),
	) );

	$wp_customize->add_setting('physiotherapy_lite_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_footer',
        'choices' => array(
        	'Left' => __('Left','physiotherapy-lite'),
            'Center' => __('Center','physiotherapy-lite'),
            'Right' => __('Right','physiotherapy-lite')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('physiotherapy_lite_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'physiotherapy-lite' ),
    ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

     // footer social icon
  	$wp_customize->add_setting( 'physiotherapy_lite_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_footer_icon',array(
		'label' => esc_html__( 'Show / Hide Footer Social Icon','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_footer'
    )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('physiotherapy_lite_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_footer_text', 
	));

	$wp_customize->add_setting( 'physiotherapy_lite_copyright_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_copyright_hide_show',array(
      'label' => esc_html__( 'Show / Hide Copyright','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_footer'
    )));

	$wp_customize->add_setting('physiotherapy_lite_copyright_background_color', array(
		'default'           => '#4167f6',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_copyright_background_color', array(
		'label'    => __('Copyright Background Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_footer',
	)));
	
	$wp_customize->add_setting('physiotherapy_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_footer_text',array(
		'label'	=> __('Copyright Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_copyright_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_copyright_font_size',array(
		'label'	=> __('Copyright Font Size','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_copyright_alignment',array(
        'default' => 'center',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_copyright_alignment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_footer',
        'settings' => 'physiotherapy_lite_copyright_alignment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

	$wp_customize->add_setting( 'physiotherapy_lite_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('physiotherapy_lite_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('physiotherapy_lite_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_footer',
		'setting'	=> 'physiotherapy_lite_scroll_to_top_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('physiotherapy_lite_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_scroll_to_top_width',array(
		'label'	=> __('Icon Width','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_scroll_to_top_height',array(
		'label'	=> __('Icon Height','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('physiotherapy_lite_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_footer',
        'settings' => 'physiotherapy_lite_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

	
	//Blog Post
	$wp_customize->add_panel( $PhysiotherapyLiteParentPanel );

	$BlogPostParentPanel = new Physiotherapy_Lite_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'physiotherapy_lite_post_settings', array(
		'title' => __( 'Post Settings', 'physiotherapy-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('physiotherapy_lite_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
    ));
    $wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	$wp_customize->add_setting('physiotherapy_lite_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_theme_options',array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','physiotherapy-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_post_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
            'One Column' => __('One Column','physiotherapy-lite'),
            'Three Columns' => __('Three Columns','physiotherapy-lite'),
            'Four Columns' => __('Four Columns','physiotherapy-lite'),
            'Grid Layout' => __('Grid Layout','physiotherapy-lite')
        ),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('physiotherapy_lite_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_toggle_postdate', 
	));

    $wp_customize->add_setting('physiotherapy_lite_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_post_settings',
		'setting'	=> 'physiotherapy_lite_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'physiotherapy_lite_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_post_settings'
    )));

    $wp_customize->add_setting('physiotherapy_lite_toggle_author_icon',array(
		'default'	=> 'far fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_post_settings',
		'setting'	=> 'physiotherapy_lite_toggle_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'physiotherapy_lite_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_author',array(
		'label' => esc_html__( 'Show / Hide Author','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_post_settings'
    )));

    $wp_customize->add_setting('physiotherapy_lite_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_post_settings',
		'setting'	=> 'physiotherapy_lite_toggle_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'physiotherapy_lite_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_post_settings'
    )));

    $wp_customize->add_setting('physiotherapy_lite_toggle_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_post_settings',
		'setting'	=> 'physiotherapy_lite_toggle_time_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'physiotherapy_lite_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_time',array(
		'label' => esc_html__( 'Show / Hide Time','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_post_settings'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
	));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_featured_image_hide_show', array(
		'label' => esc_html__( 'Show / Hide Featured Image','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_post_settings'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'physiotherapy_lite_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('physiotherapy_lite_blog_post_featured_image_dimension',array(
       'default' => 'default',
       'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
	));
  	$wp_customize->add_control('physiotherapy_lite_blog_post_featured_image_dimension',array(
		'type' => 'select',
		'label'	=> __('Blog Post Featured Image Dimension','physiotherapy-lite'),
		'section'	=> 'physiotherapy_lite_post_settings',
		'choices' => array(
		'default' => __('Default','physiotherapy-lite'),
		'custom' => __('Custom Image Size','physiotherapy-lite'),
      ),
  	));

	$wp_customize->add_setting('physiotherapy_lite_blog_post_featured_image_custom_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('physiotherapy_lite_blog_post_featured_image_custom_width',array(
		'label'	=> __('Featured Image Custom Width','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'physiotherapy-lite' ),),
		'section'=> 'physiotherapy_lite_post_settings',
		'type'=> 'text',
		'active_callback' => 'physiotherapy_lite_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('physiotherapy_lite_blog_post_featured_image_custom_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_blog_post_featured_image_custom_height',array(
		'label'	=> __('Featured Image Custom Height','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
    	'placeholder' => __( '10px', 'physiotherapy-lite' ),),
		'section'=> 'physiotherapy_lite_post_settings',
		'type'=> 'text',
		'active_callback' => 'physiotherapy_lite_blog_post_featured_image_dimension'
	));

    $wp_customize->add_setting( 'physiotherapy_lite_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_post_settings',
		'type'        => 'range',
		'settings'    => 'physiotherapy_lite_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('physiotherapy_lite_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','physiotherapy-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('physiotherapy_lite_blog_page_posts_settings',array(
        'default' => 'Into Blocks',
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_blog_page_posts_settings',array(
        'type' => 'select',
        'label' => __('Display Blog Posts','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_post_settings',
        'choices' => array(
        	'Into Blocks' => __('Into Blocks','physiotherapy-lite'),
            'Without Blocks' => __('Without Blocks','physiotherapy-lite')
        ),
	) );

    $wp_customize->add_setting('physiotherapy_lite_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_post_settings',
        'choices' => array(
        	'Content' => __('Content','physiotherapy-lite'),
            'Excerpt' => __('Excerpt','physiotherapy-lite'),
            'No Content' => __('No Content','physiotherapy-lite')
        ),
	) );

	$wp_customize->add_setting('physiotherapy_lite_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_blog_pagination_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_post_settings'
    )));

	$wp_customize->add_setting( 'physiotherapy_lite_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
    ));
    $wp_customize->add_control( 'physiotherapy_lite_blog_pagination_type', array(
        'section' => 'physiotherapy_lite_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'physiotherapy-lite' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'physiotherapy-lite' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'physiotherapy-lite' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'physiotherapy_lite_button_settings', array(
		'title' => __( 'Button Settings', 'physiotherapy-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('physiotherapy_lite_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_button_text', 
	));

	$wp_customize->add_setting('physiotherapy_lite_button_text',array(
		'default'=> esc_html__( 'Read More', 'physiotherapy-lite' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_text',array(
		'label'	=> __('Add Button Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('physiotherapy_lite_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_font_size',array(
		'label'	=> __('Button Font Size','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'physiotherapy-lite' ),
    ),
    'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'physiotherapy_lite_button_settings',
	));

	$wp_customize->add_setting( 'physiotherapy_lite_button_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('physiotherapy_lite_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'physiotherapy-lite' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'physiotherapy_lite_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('physiotherapy_lite_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','physiotherapy-lite'),
		'choices' => array(
            'Uppercase' => __('Uppercase','physiotherapy-lite'),
            'Capitalize' => __('Capitalize','physiotherapy-lite'),
            'Lowercase' => __('Lowercase','physiotherapy-lite'),
        ),
		'section'=> 'physiotherapy_lite_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'physiotherapy_lite_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'physiotherapy-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('physiotherapy_lite_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_related_post_title', 
	));

    $wp_customize->add_setting( 'physiotherapy_lite_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_related_post',array(
		'label' => esc_html__( 'Show / Hide Related Post','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_related_posts_settings'
    )));

    $wp_customize->add_setting('physiotherapy_lite_related_post_title',array(
		'default'=> 'Related Post',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_related_post_title',array(
		'label'	=> __('Add Related Post Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('physiotherapy_lite_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_float'
	));
	$wp_customize->add_control('physiotherapy_lite_related_posts_count',array(
		'label'	=> __('Add Related Post Count','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'physiotherapy_lite_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Posts Settings
	$wp_customize->add_section( 'physiotherapy_lite_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'physiotherapy-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('physiotherapy_lite_single_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new physiotherapy_lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_single_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_single_blog_settings',
		'setting'	=> 'physiotherapy_lite_single_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'physiotherapy_lite_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_postdate',array(
	    'label' => esc_html__( 'Show / Hide Date','physiotherapy-lite' ),
	   'section' => 'physiotherapy_lite_single_blog_settings'
	)));

	$wp_customize->add_setting('physiotherapy_lite_single_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new physiotherapy_lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_single_author_icon',array(
		'label'	=> __('Add Author Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_single_blog_settings',
		'setting'	=> 'physiotherapy_lite_single_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'physiotherapy_lite_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_author',array(
	    'label' => esc_html__( 'Show / Hide Author','physiotherapy-lite' ),
	    'section' => 'physiotherapy_lite_single_blog_settings'
	)));

   	$wp_customize->add_setting('physiotherapy_lite_single_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new physiotherapy_lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_single_comments_icon',array(
		'label'	=> __('Add Comments Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_single_blog_settings',
		'setting'	=> 'physiotherapy_lite_single_comments_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'physiotherapy_lite_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_comments',array(
	    'label' => esc_html__( 'Show / Hide Comments','physiotherapy-lite' ),
	    'section' => 'physiotherapy_lite_single_blog_settings'
	)));

  	$wp_customize->add_setting('physiotherapy_lite_single_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new physiotherapy_lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_single_time_icon',array(
		'label'	=> __('Add Time Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_single_blog_settings',
		'setting'	=> 'physiotherapy_lite_single_time_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'physiotherapy_lite_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
	) );
	$wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_time',array(
	    'label' => esc_html__( 'Show / Hide Time','physiotherapy-lite' ),
	    'section' => 'physiotherapy_lite_single_blog_settings'
	)));

	$wp_customize->add_setting( 'physiotherapy_lite_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_post_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Breadcrumb','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_single_blog_settings'
    )));

    // Single Posts Category
  	$wp_customize->add_setting( 'physiotherapy_lite_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
  	$wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_post_category',array(
		'label' => esc_html__( 'Show / Hide Category','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_single_blog_settings'
    )));

	$wp_customize->add_setting( 'physiotherapy_lite_toggle_tags',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
	));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_toggle_tags', array(
		'label' => esc_html__( 'Show / Hide Tags','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_single_blog_settings'
    )));

	$wp_customize->add_setting('physiotherapy_lite_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','physiotherapy-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
	));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Show / Hide Post Navigation','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_single_blog_settings'
    )));

	//navigation text
	$wp_customize->add_setting('physiotherapy_lite_single_blog_prev_navigation_text',array(
		'default'=> 'PREVIOUS',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_single_blog_next_navigation_text',array(
		'default'=> 'NEXT',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_single_blog_comment_title',array(
		'default'=> 'Leave a Reply',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_single_blog_comment_button_text',array(
		'default'=> 'Post Comment',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','physiotherapy-lite'),
		'description'	=> __('Enter a value in %. Example:50%','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_single_blog_settings',
		'type'=> 'text'
	));

	// Grid layout setting
	$wp_customize->add_section( 'physiotherapy_lite_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'physiotherapy-lite' ),
		'panel' => 'blog_post_parent_panel',
	));

  	$wp_customize->add_setting('physiotherapy_lite_grid_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new physiotherapy_lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_grid_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_grid_layout_settings',
		'setting'	=> 'physiotherapy_lite_grid_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'physiotherapy_lite_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_grid_postdate',array(
        'label' => esc_html__( 'Show / Hide Post Date','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_grid_layout_settings'
    )));

	$wp_customize->add_setting('physiotherapy_lite_grid_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new physiotherapy_lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_grid_author_icon',array(
		'label'	=> __('Add Author Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_grid_layout_settings',
		'setting'	=> 'physiotherapy_lite_grid_author_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'physiotherapy_lite_grid_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_grid_author',array(
		'label' => esc_html__( 'Show / Hide Author','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_grid_layout_settings'
    )));

   	$wp_customize->add_setting('physiotherapy_lite_grid_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new physiotherapy_lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_grid_comments_icon',array(
		'label'	=> __('Add Comments Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_grid_layout_settings',
		'setting'	=> 'physiotherapy_lite_grid_comments_icon',
		'type'		=> 'icon'
	)));

    $wp_customize->add_setting( 'physiotherapy_lite_grid_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_grid_comments',array(
		'label' => esc_html__( 'Show / Hide Comments','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_grid_layout_settings'
    )));

 	$wp_customize->add_setting('physiotherapy_lite_grid_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_grid_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','physiotherapy-lite'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','physiotherapy-lite'),
		'section'=> 'physiotherapy_lite_grid_layout_settings',
		'type'=> 'text'
	));  

  	$wp_customize->add_setting('physiotherapy_lite_display_grid_posts_settings',array(
	    'default' => 'Into Blocks',
	    'transport' => 'refresh',
	    'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_display_grid_posts_settings',array(
	    'type' => 'select',
	    'label' => __('Display Grid Posts','physiotherapy-lite'),
	    'section' => 'physiotherapy_lite_grid_layout_settings',
	    'choices' => array(
	    	'Into Blocks' => __('Into Blocks','physiotherapy-lite'),
	      	'Without Blocks' => __('Without Blocks','physiotherapy-lite')
	    ),
	) );

	$wp_customize->add_setting('physiotherapy_lite_grid_button_text',array(
		'default'=> esc_html__('Read More','physiotherapy-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_grid_button_text',array(
		'label'	=> esc_html__('Add Button Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_grid_layout_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_grid_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_grid_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_grid_layout_settings',
		'type'=> 'text'
	));

   // other settings
	$OtherParentPanel = new Physiotherapy_Lite_WP_Customize_Panel( $wp_customize, 'physiotherapy_lite_other_panel_id', array(
		'title' => __( 'Others Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id',
	));

	$wp_customize->add_panel( $OtherParentPanel );

	// Layout
	$wp_customize->add_section( 'physiotherapy_lite_left_right', array(
    	'title'      => esc_html__( 'General Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_other_panel_id'
	) );

	$wp_customize->add_setting('physiotherapy_lite_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control(new Physiotherapy_Lite_Image_Radio_Control($wp_customize, 'physiotherapy_lite_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','physiotherapy-lite'),
        'description' => __('Here you can change the width layout of Website.','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('physiotherapy_lite_page_layout',array(
        'default' => 'One Column',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','physiotherapy-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
            'One Column' => __('One Column','physiotherapy-lite')
        ),
	) );

	$wp_customize->add_setting( 'physiotherapy_lite_single_page_breadcrumb',array(
		'default' => 0,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_single_page_breadcrumb',array(
		'label' => esc_html__( 'Show / Hide Page Breadcrumb','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_left_right'
    )));

	//Wow Animation
	$wp_customize->add_setting( 'physiotherapy_lite_animation',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_animation',array(
        'label' => esc_html__( 'Show / Hide Animation ','physiotherapy-lite' ),
        'description' => __('Here you can disable overall site animation effect','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right'
    )));

    $wp_customize->add_setting('physiotherapy_lite_reset_all_settings',array(
      'sanitize_callback'	=> 'sanitize_text_field',
   	));
   	$wp_customize->add_control(new Physiotherapy_Lite_Reset_Custom_Control($wp_customize, 'physiotherapy_lite_reset_all_settings',array(
      'type' => 'reset_control',
      'label' => __('Reset All Settings', 'physiotherapy-lite'),
      'description' => 'physiotherapy_lite_reset_all_settings',
      'section' => 'physiotherapy_lite_left_right'
   	)));

	//Pre-Loader
	$wp_customize->add_setting( 'physiotherapy_lite_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_loader_enable',array(
        'label' => esc_html__( 'Show / Hide Pre-Loader','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_left_right'
    )));

	$wp_customize->add_setting('physiotherapy_lite_preloader_bg_color', array(
		'default'           => '#4167f6',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_left_right',
	)));

	$wp_customize->add_setting('physiotherapy_lite_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_left_right',
	)));

	$wp_customize->add_setting('physiotherapy_lite_preloader_bg_img',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'physiotherapy_lite_preloader_bg_img',array(
        'label' => __('Preloader Background Image','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right'
	)));

    //404 Page Setting
	$wp_customize->add_section('physiotherapy_lite_404_page',array(
		'title'	=> __('404 Page Settings','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_other_panel_id',
	));	

	$wp_customize->add_setting('physiotherapy_lite_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_404_page_title',array(
		'label'	=> __('Add Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_404_page_content',array(
		'label'	=> __('Add Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_404_page_button_text',array(
		'label'	=> __('Add Button Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'GO BACK', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_404_page',
		'type'=> 'text'
	));

	//No Result Page Setting
	$wp_customize->add_section('physiotherapy_lite_no_results_page',array(
		'title'	=> __('No Results Page Settings','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_other_panel_id',
	));	

	$wp_customize->add_setting('physiotherapy_lite_no_results_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_no_results_page_title',array(
		'label'	=> __('Add Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Nothing Found', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_no_results_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_no_results_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('physiotherapy_lite_no_results_page_content',array(
		'label'	=> __('Add Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_no_results_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('physiotherapy_lite_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_other_panel_id',
	));	

	$wp_customize->add_setting('physiotherapy_lite_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_social_icon_padding',array(
		'label'	=> __('Icon Padding','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_social_icon_width',array(
		'label'	=> __('Icon Width','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_social_icon_height',array(
		'label'	=> __('Icon Height','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_social_icon_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_social_icon_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_social_icon_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Responsive Media Settings
	$wp_customize->add_section('physiotherapy_lite_responsive_media',array(
		'title'	=> __('Responsive Media','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_other_panel_id',
	));

	$wp_customize->add_setting( 'physiotherapy_lite_resp_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_resp_topbar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Topbar','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_stickyheader_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_stickyheader_hide_show',array(
      'label' => esc_html__( 'Sticky Header','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_resp_slider_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_resp_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_sidebar_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_sidebar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Sidebar','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting( 'physiotherapy_lite_resp_scroll_top_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_resp_scroll_top_hide_show',array(
      'label' => esc_html__( 'Show / Hide Scroll To Top','physiotherapy-lite' ),
      'section' => 'physiotherapy_lite_responsive_media'
    )));

    $wp_customize->add_setting('physiotherapy_lite_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'physiotherapy_lite_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'physiotherapy-lite'),
		'section'  => 'physiotherapy_lite_responsive_media',
	)));

    $wp_customize->add_setting('physiotherapy_lite_res_open_menu_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_res_open_menu_icon',array(
		'label'	=> __('Add Open Menu Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_responsive_media',
		'setting'	=> 'physiotherapy_lite_res_open_menu_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('physiotherapy_lite_res_close_menus_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new Physiotherapy_Lite_Fontawesome_Icon_Chooser(
        $wp_customize,'physiotherapy_lite_res_close_menus_icon',array(
		'label'	=> __('Add Close Menu Icon','physiotherapy-lite'),
		'transport' => 'refresh',
		'section'	=> 'physiotherapy_lite_responsive_media',
		'setting'	=> 'physiotherapy_lite_res_close_menus_icon',
		'type'		=> 'icon'
	)));

    //Woocommerce settings
	$wp_customize->add_section('physiotherapy_lite_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'physiotherapy-lite'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

    //Shop Page Featured Image
	$wp_customize->add_setting( 'physiotherapy_lite_shop_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_shop_featured_image_border_radius', array(
		'label'       => esc_html__( 'Shop Page Featured Image Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'physiotherapy_lite_shop_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_shop_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Shop Page Featured Image Box Shadow','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'physiotherapy_lite_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_woocommerce_shop_page_sidebar', ) );

    //Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'physiotherapy_lite_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Shop Page Sidebar','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_woocommerce_section'
    )));

    $wp_customize->add_setting('physiotherapy_lite_shop_page_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_shop_page_layout',array(
        'type' => 'select',
        'label' => __('Shop Page Sidebar Layout','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
        ),
	) );

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'physiotherapy_lite_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'physiotherapy_lite_customize_partial_physiotherapy_lite_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'physiotherapy_lite_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Show / Hide Single Product Sidebar','physiotherapy-lite' ),
		'section' => 'physiotherapy_lite_woocommerce_section'
    )));

    $wp_customize->add_setting('physiotherapy_lite_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
        ),
	) );

    //Products per page
    $wp_customize->add_setting('physiotherapy_lite_products_per_page',array(
		'default'=> '9',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_float'
	));
	$wp_customize->add_control('physiotherapy_lite_products_per_page',array(
		'label'	=> __('Products Per Page','physiotherapy-lite'),
		'description' => __('Display on shop page','physiotherapy-lite'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'number',
	));

    //Products per row
    $wp_customize->add_setting('physiotherapy_lite_products_per_row',array(
		'default'=> '3',
		'sanitize_callback'	=> 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_products_per_row',array(
		'label'	=> __('Products Per Row','physiotherapy-lite'),
		'description' => __('Display on shop page','physiotherapy-lite'),
		'choices' => array(
            '2' => '2',
			'3' => '3',
			'4' => '4',
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'select',
	));

	//Products padding
	$wp_customize->add_setting('physiotherapy_lite_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'physiotherapy_lite_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
    $wp_customize->add_setting( 'physiotherapy_lite_products_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('physiotherapy_lite_products_btn_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_products_btn_padding_top_bottom',array(
		'label'	=> __('Products Button Padding Top Bottom','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_products_btn_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_products_btn_padding_left_right',array(
		'label'	=> __('Products Button Padding Left Right','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_products_button_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_products_button_border_radius', array(
		'label'       => esc_html__( 'Products Button Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('physiotherapy_lite_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_woocommerce_sale_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_woocommerce_sale_padding_top_bottom',array(
		'label'	=> __('Sale Padding Top Bottom','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('physiotherapy_lite_woocommerce_sale_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_woocommerce_sale_padding_left_right',array(
		'label'	=> __('Sale Padding Left Right','physiotherapy-lite'),
		'description'	=> __('Enter a value in pixels. Example:20px','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_woocommerce_sale_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'physiotherapy_lite_sanitize_number_range'
	) );
	$wp_customize->add_control( 'physiotherapy_lite_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','physiotherapy-lite' ),
		'section'     => 'physiotherapy_lite_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    // Related Product
    $wp_customize->add_setting( 'physiotherapy_lite_related_product_show_hide',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ) );
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_related_product_show_hide',array(
        'label' => esc_html__( 'Show / Hide Related product','physiotherapy-lite' ),
        'section' => 'physiotherapy_lite_woocommerce_section'
    )));  

    // Has to be at the top
	$wp_customize->register_panel_type( 'Physiotherapy_Lite_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'Physiotherapy_Lite_WP_Customize_Section' );
}

add_action( 'customize_register', 'physiotherapy_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class Physiotherapy_Lite_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'physiotherapy_lite_panel';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
    	}
  	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class Physiotherapy_Lite_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'physiotherapy_lite_section';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
    	}
  	}
}

// Enqueue our scripts and styles
function physiotherapy_lite_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/assets/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'physiotherapy_lite_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Physiotherapy_Lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Physiotherapy_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Physiotherapy_Lite_Customize_Section_Pro( $manager,'physiotherapy_lite_upgrade_pro_link', array(
			'priority'   => 1,
			'title'    => esc_html__( 'PHYSIOTHERAPY PRO', 'physiotherapy-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'physiotherapy-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/physiotherapy-wordpress-theme/'),
		) )	);

		$manager->add_section(new Physiotherapy_Lite_Customize_Section_Pro($manager,'physiotherapy_lite_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'physiotherapy-lite' ),
			'pro_text' => esc_html__( 'DOCS', 'physiotherapy-lite' ),
			'pro_url'  => esc_url('https://preview.vwthemesdemo.com/docs/free-physiotherapy/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'physiotherapy-lite-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'physiotherapy-lite-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );

		wp_localize_script(
		'physiotherapy-lite-customize-controls',
		'physiotherapy_lite_customizer_params',
		array(
			'ajaxurl' =>	admin_url( 'admin-ajax.php' )
		));
	}
}

// Doing this customizer thang!
Physiotherapy_Lite_Customize::get_instance();